Publications and Citation
=========================

**Publications:**
We have two publications linked to our de novo gene annotation format and the 
**denofo** `toolkit <https://github.com/EDohmen/denofo>`_:

- Application Note: (`coming soon <https://github.com/EDohmen/denofo>`_) An Application Note introducing the **denofo** toolkit.
- Review: (`coming soon <https://github.com/EDohmen/denofo>`_) A review introducing the concepts and decisions for the standardized de novo annotation format.

**Citation:**
If you used **denofo** for your work, please cite the Application Note linked above.
